=== modified file '.bzrignore'
--- .bzrignore	2014-07-08 16:17:02 +0000
+++ .bzrignore	2014-07-25 08:22:52 +0000
@@ -19,3 +19,4 @@
 .cproject
 .project
 .settings
+__pycache__

=== modified file 'plugins/cellular/Components/SimEditor.qml'
--- plugins/cellular/Components/SimEditor.qml	2014-07-24 16:04:51 +0000
+++ plugins/cellular/Components/SimEditor.qml	2014-07-25 08:22:52 +0000
@@ -23,45 +23,143 @@
 
 Column {
 
+    id: simList
+
     anchors.left: parent.left
     anchors.right: parent.right
 
+    signal renamed (string path, string name)
+
+    states: [
+        State {
+            name: "editing"
+            PropertyChanges {
+                target: editor
+                visible: true
+            }
+        },
+        State {
+            extend: "editing"
+            name: "editingSim1"
+            PropertyChanges {
+                target: nameField
+                path: sim1.path
+                text: sim1.name
+            }
+            ParentChange {
+                target: editor
+                parent: sim1Placeholder
+            }
+        },
+        State {
+            extend: "editing"
+            name: "editingSim2"
+            PropertyChanges {
+                target: nameField
+                path: sim2.path
+                text: sim2.name
+            }
+            ParentChange {
+                target: editor
+                parent: sim2Placeholder
+            }
+        }
+    ]
+
     ListItem.Standard {
         text: i18n.tr("Edit SIM Name")
     }
 
-    ListItem.Standard {
-        text: sim1.title
-        progression: true
-        onClicked: {
-
-        }
-    }
-
-    ListItem.Standard {
-        text: sim2.title
-        progression: true
-    }
-
-    Item {
-
+    Column {
+
+        anchors.left: parent.left
+        anchors.right: parent.right
+        spacing: units.gu(2)
+
+        ListItem.Standard {
+            id: sim1Item
+            text: sim1.title
+            progression: true
+            onClicked: {
+                simList.state = "editingSim1";
+            }
+        }
+
+        Column {
+            id: sim1Placeholder
+        }
+    }
+
+    Column {
+
+        anchors.left: parent.left
+        anchors.right: parent.right
+        spacing: units.gu(2)
+
+        ListItem.Standard {
+            id: sim2Item
+            text: sim2.title
+            progression: true
+            onClicked: {
+                simList.state = "editingSim2";
+            }
+        }
+
+        Column {
+            id: sim2Placeholder
+        }
+    }
+
+    Column {
         id: editor
-        height: childrenRect.height
+        property alias newPath: nameField.path
+        property alias newName: nameField.text
+        visible: false
+
+        width: simList.width - units.gu(4)
+        spacing: units.gu(2)
         anchors {
-            left: parent.left
-            right: parent.right
+            horizontalCenter: simList.horizontalCenter
         }
 
         TextField {
-            id: field
-            text: "sim foo"
+            property string path
+            id: nameField
             maximumLength: 30
-            width: parent.width - units.gu(4)
-            anchors {
-                topMargin: units.gu(2)
-                horizontalCenter: parent.horizontalCenter
-            }
-        }
-
+            width: simList.width - units.gu(4)
+        }
+
+        Row {
+
+            spacing: units.gu(2)
+
+            Button {
+                id: cancel
+                objectName: "cancelRename"
+                gradient: UbuntuColors.greyGradient
+                text: i18n.tr("Cancel")
+                width: (editor.width / 2) - units.gu(1)
+                onClicked: {
+                    simList.state = "";
+                }
+            }
+
+            Button {
+                id: rename
+                objectName: "doRename"
+                text: i18n.tr("OK")
+                width: (editor.width / 2) - units.gu(1)
+                action: renameAction
+            }
+        }
+
+        Action {
+            id: renameAction
+            onTriggered: {
+                renamed(editor.newPath, editor.newName);
+                simList.state = "";
+            }
+        }
     }
 }
+

=== modified file 'plugins/cellular/PageComponent.qml'
--- plugins/cellular/PageComponent.qml	2014-07-24 20:29:51 +0000
+++ plugins/cellular/PageComponent.qml	2014-07-25 08:22:52 +0000
@@ -185,6 +185,15 @@
 
             SimEditor {
                 enabled: root.state === "dualSim"
+                onRenamed: {
+                    console.warn('caught signal: renamed(', path, name, ')');
+                    var s = systemSettingsSettings;
+                    if (path === s.sim1Path) {
+                        s.sim1Name = name;
+                    } else {
+                        s.sim2Name = name;
+                    }
+                }
             }
 
         }
@@ -194,8 +203,11 @@
         id: systemSettingsSettings
         schema.id: "com.ubuntu.touch.system-settings"
         onChanged: {
-            if (key == "sim1Name") {
-
+            var s = systemSettingsSettings;
+            if (key === "sim1Name") {
+                sim1.name = s.sim1Name;
+            } else if (key === "sim2Name") {
+                sim2.name = s.sim2Name;
             }
         }
         Component.onCompleted: {

=== modified file 'tests/autopilot/ubuntu_system_settings/tests/test_cellular.py'
--- tests/autopilot/ubuntu_system_settings/tests/test_cellular.py	2014-07-24 20:29:51 +0000
+++ tests/autopilot/ubuntu_system_settings/tests/test_cellular.py	2014-07-25 08:22:52 +0000
@@ -503,5 +503,5 @@
         self.assertThat(manual, NotEquals(None))
 
     def test_two_modems(self):
-        sleep(3)
+        sleep(9)
         self.assertFalse(True)

